#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-yaml
version:              1.2.12
visibility:           public
id:                   dhall-yaml-1.2.12-5NQunXvWqM5HDZES6AXbk8
key:                  dhall-yaml-1.2.12-5NQunXvWqM5HDZES6AXbk8
license:              GPL-3.0-only
copyright:            2019 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and YAML
description:
    Use this package if you want to convert between Dhall expressions and YAML.
    You can use this package as a library or an executable:

    * See the "Dhall.Yaml" module if you want to use this package as a library

    * Use the @dhall-to-yaml-ng@ program from this package if you want an executable

category:             Compiler
abi:                  baafa4518dc23907f359e7efcaa77fd3
exposed:              True
exposed-modules:      Dhall.Yaml Dhall.YamlToDhall
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-yaml-1.2.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-yaml-1.2.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-yaml-1.2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-yaml
hs-libraries:         HSdhall-yaml-1.2.12-5NQunXvWqM5HDZES6AXbk8
depends:
    HsYAML-0.2.1.5-AxnHllZIOpo4UQZN0wRhUD
    HsYAML-aeson-0.2.0.2-JjOjzW7SGBpJj6725MSHTA
    aeson-2.2.2.0-JRwGfw4G4faAdkvjZDffZf base-4.18.2.1
    bytestring-0.11.5.3 dhall-1.42.3-9z7lqL4zR6A3xSdlAIslDl
    dhall-json-1.7.12-KqPtWbWBJpeKAWXgBdD02M
    optparse-applicative-0.18.1.0-1bx6NtkYgnV6peHQkP2ZMq text-2.0.2
    vector-0.13.2.0-Bce9rIW4lAD9r12sFleKX

haddock-interfaces:   /usr/share/doc/dhall-yaml/html/dhall-yaml.haddock
haddock-html:         /usr/share/doc/dhall-yaml/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

